# 具体例

## 日付表現 1

```
【2021年1月21日】大統領宣誓を行うジョー・バイデン。 20日、アメリカ合衆国の首都ワシントンD.C.において、大統領就任式が行われた。
```

```xml
<TIMEX3 tid="t0" type="DATE" value="2021-01-21" text="2021年1月21日">,
<TIMEX3 tid="t1" type="DATE" value="XXXX-XX-20" text="20日">
```

[バイデン米大統領の就任式が開催される \- ウィキニュース](https://ja.wikinews.org/wiki/%E3%83%90%E3%82%A4%E3%83%87%E3%83%B3%E7%B1%B3%E5%A4%A7%E7%B5%B1%E9%A0%98%E3%81%AE%E5%B0%B1%E4%BB%BB%E5%BC%8F%E3%81%8C%E9%96%8B%E5%82%AC%E3%81%95%E3%82%8C%E3%82%8B)

!!! Tips
    文中の`20日`のように、たとえ前後の文脈から日付が推定できたとしても、ja-timexでは表層表現の情報のみを利用します。

---

## 日付表現 2

```
気象庁が大雪とその被害について命名したのは1963年の「昭和38年1月豪雪」（三八豪雪）以外に例が無く、43年ぶり史上二度目の命名となった。
```

```xml
<TIMEX3 tid="t0" type="DATE" value="1963-XX-XX" text="1963年">
<TIMEX3 tid="t1" type="DATE" value="1963-01-XX" text="昭和38年1月">
<TIMEX3 tid="t2" type="DATE" value="0043-XX-XX" text="43年">
```

[今冬の大雪は『平成18年豪雪』、死者数は戦後2番目に \- ウィキニュース](https://ja.wikinews.org/wiki/%E4%BB%8A%E5%86%AC%E3%81%AE%E5%A4%A7%E9%9B%AA%E3%81%AF%E3%80%8E%E5%B9%B3%E6%88%9018%E5%B9%B4%E8%B1%AA%E9%9B%AA%E3%80%8F%E3%80%81%E6%AD%BB%E8%80%85%E6%95%B0%E3%81%AF%E6%88%A6%E5%BE%8C2%E7%95%AA%E7%9B%AE%E3%81%AB)


!!! Tips
    `昭和`といった和暦は、西暦に変換されます。

---

## 時刻表現

```
気象庁によれば、大型で非常に強い台風第13号 「タリム」は31日午後10時45分（日本時間、UTC+9）現在、台湾の東海上にあって、西北西に進んでいる。
```

```xml
<TIMEX3 tid="t0" type="DATE" value="XXXX-XX-31" text="31日">
<TIMEX3 tid="t1" type="TIME" value="T22-45-XX" text="午後10時45分">
```

[台風13号、先島諸島から台湾へ−14号も沖縄に向かう \- ウィキニュース](https://ja.wikinews.org/wiki/%E5%8F%B0%E9%A2%A813%E5%8F%B7%E3%80%81%E5%85%88%E5%B3%B6%E8%AB%B8%E5%B3%B6%E3%81%8B%E3%82%89%E5%8F%B0%E6%B9%BE%E3%81%B8%E2%88%9214%E5%8F%B7%E3%82%82%E6%B2%96%E7%B8%84%E3%81%AB%E5%90%91%E3%81%8B%E3%81%86)

!!! Tips
    `午前`、`午後`などが付く12時間表記は、24時間表記に変換されます。

---

## 頻度集合表現

```
両リーグで異なっている試合競技方法の調整などの会議を週1回程度行い、10月末までに合意することを目指している
```

```xml
<TIMEX3 tid="t0" type="SET" value="P1W" freq="1X" text="週1回">
<TIMEX3 tid="t1" type="DATE" value="XXXX-10-XX" mod="END" text="10月末">
```

[日本のバスケットボールリーグ一本化へ向けた組織委員会発足 \- ウィキニュース](https://ja.wikinews.org/wiki/%E6%97%A5%E6%9C%AC%E3%81%AE%E3%83%90%E3%82%B9%E3%82%B1%E3%83%83%E3%83%88%E3%83%9C%E3%83%BC%E3%83%AB%E3%83%AA%E3%83%BC%E3%82%B0%E4%B8%80%E6%9C%AC%E5%8C%96%E3%81%B8%E5%90%91%E3%81%91%E3%81%9F%E7%B5%84%E7%B9%94%E5%A7%94%E5%93%A1%E4%BC%9A%E7%99%BA%E8%B6%B3)

!!! Tips
    `10月末`のように日付に付加情報が付いている場合は、`@mod=END`のように表現されます。

--- 

## 持続時間表現 1

```
奈良市環境清美部の男性職員 (42) が、2001年からの5年9カ月余りで8日しか出勤していないのにも関わらず、給与がほぼ満額支給されていたことが明らかになった。
```

```xml
<TIMEX3 tid="t0" type="DATE" value="2001-XX-XX" text="2001年">
<TIMEX3 tid="t1" type="DURATION" value="P5Y9M" text="5年9カ月">
<TIMEX3 tid="t2" type="DATE" value="XXXX-XX-08" text="8日">
```

[奈良市職員、5年間ほとんど出勤せず給与満額 \- ウィキニュース](https://ja.wikinews.org/wiki/%E5%A5%88%E8%89%AF%E5%B8%82%E8%81%B7%E5%93%A1%E3%80%815%E5%B9%B4%E9%96%93%E3%81%BB%E3%81%A8%E3%82%93%E3%81%A9%E5%87%BA%E5%8B%A4%E3%81%9B%E3%81%9A%E7%B5%A6%E4%B8%8E%E6%BA%80%E9%A1%8D)


!!! Tips
    生物の年齢は、数値表現であって時間情報表現ではないので取得しません

---

## 持続時間表現 2

```
12月14日、日本の宇宙航空研究開発機構（JAXA）は、今月6日に地球に帰還した小惑星探査機「はやぶさ2」のカプセルから、リュウグウ由来とみられる砂粒状の粒子を採取することに成功したと発表した
```

```xml
<TIMEX3 tid="t0" type="DATE" value="XXXX-12-14" text="12月14日">,
<TIMEX3 tid="t1" type="DURATION" value="P0M" mod="NOW" text="今月">,
<TIMEX3 tid="t2" type="DATE" value="XXXX-XX-06" text="6日">
```

[はやぶさ2帰還カプセル 小惑星リュウグウ由来の粒子とガスを確認 \- ウィキニュース](https://ja.wikinews.org/wiki/%E3%81%AF%E3%82%84%E3%81%B6%E3%81%952%E5%B8%B0%E9%82%84%E3%82%AB%E3%83%97%E3%82%BB%E3%83%AB_%E5%B0%8F%E6%83%91%E6%98%9F%E3%83%AA%E3%83%A5%E3%82%A6%E3%82%B0%E3%82%A6%E7%94%B1%E6%9D%A5%E3%81%AE%E7%B2%92%E5%AD%90%E3%81%A8%E3%82%AC%E3%82%B9%E3%82%92%E7%A2%BA%E8%AA%8D)

!!! Warning
    `今月6日`は`今月`,`6日`に分割してタグ付けを行います。成澤\[2\]では1つのまとまりとして扱うように定義されていましたが、ja-timexでは分割します。
    
    その理由として、TIMEX3タグの定義上は日付表現として「いずれかの月」か「そもそも月の情報が不明」かを区別することができません。`XXXX-XX-06`という表記しかできず、今回の場合は`今月6日`のうちの`今月`の情報が表層表現から欠落してしまうため、情報の欠損を防ぐために分割しています。
    
    `今月`は、表層表現からではどの月かを推定することが不可能なため、日付表現とは扱わず持続時間表現として扱います。

!!! Tips
    持続時間表現としての`今月`は、`value="P0M" mod="NOW"`という2つの組み合わせで表現します。これは`先月`なら`value="P1M" mod="BEFORE"`、`来月`なら`value="P1M" mod="AFTER"`と表現することを踏まえたものです。

